@@ -27,8 +27,6 @@ class BaseLocationStorage(object):
             return self.location_model.objects.filter(pk=location.id).exists()
         except AttributeError:
             raise
-            return False
-
 
     def _get_by_id(self, location_id):
         return get_class(settings.GEOIP_LOCATION_MODEL).objects.get(pk=location_id)
@@ -84,7 +82,7 @@ class LocationCookieStorage(BaseLocationStorage):
             key=settings.GEOIP_COOKIE_NAME,
             value=value,
             domain=self._get_cookie_domain(),
-            expires=datetime.now() + timedelta(seconds=settings.GEOIP_COOKIE_EXPIRES))
+            expires=datetime.utcnow() + timedelta(seconds=settings.GEOIP_COOKIE_EXPIRES))
 
     def _should_update_cookie(self, new_value):
         # process_request never completed, don't need to update cookie
